PyACTUp is a lightweight Python implementation of a subset of the
ACT-R cognitive architecture’s Declarative Memory, suitable for
incorporating into other Python models and applications. Its design
is inspired by the ACT-UP cognitive modeling toolbox.

There is [online documentation of PyACTUp](http://halle.psy.cmu.edu/pyactup/),
and the [sources](https://github.com/dfmorrison/pyactup/) are on GitHub.

The latest version of PyACTUp can be download and install from PyPi with pip:

    pip install pyactup

Use of a virtual environment for Python, such as venv or Anaconda is recommended.

PyACTUp requires Python version 3.8 or later.

PyACTUp is released under the following MIT style license:

Copyright (c) 2018-2022 Carnegie Mellon University

Permission is hereby granted, free of charge, to any person obtaining a copy of this
software and associated documentation files (the "Software"), to deal in the Software
without restriction, including without limitation the rights to use, copy, modify,
merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to the following
conditions:

The above copyright notice and this permission notice shall be included in all copies
or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
